@@ -391,6 +391,23 @@ def uuidsToCatalogBrains(uuids=[],
     return brains
 
 
+def uuidToCatalogBrain(uuid,
+                       ordered=False,
+                       query={},
+                       check_contained_uids=False,
+                       unrestricted=False):
+    """Shortcut to call uuidsToCatalogBrains to get one single element."""
+    res = uuidsToCatalogBrains(
+        uuids=[uuid],
+        ordered=ordered,
+        query=query,
+        check_contained_uids=check_contained_uids,
+        unrestricted=unrestricted)
+    if res:
+        res = res[0]
+    return res
+
+
 def _contained_objects(obj, only_unindexed=False):
     """Return every elements contained in p_obj, incuding sub_elements.
        If p_only_unindexed=True, then we only return elements that are not indexed"""
@@ -442,6 +459,23 @@ def uuidsToObjects(uuids=[], ordered=False, query={}, check_contained_uids=False
     return res
 
 
+def uuidToObject(uuid,
+                 ordered=False,
+                 query={},
+                 check_contained_uids=False,
+                 unrestricted=False):
+    """Shortcut to call uuidsToObjects to get one single element."""
+    res = uuidsToObjects(
+        uuids=[uuid],
+        ordered=ordered,
+        query=query,
+        check_contained_uids=check_contained_uids,
+        unrestricted=unrestricted)
+    if res:
+        res = res[0]
+    return res
+
+
 def disable_link_integrity_checks():
     """ """
     ptool = queryUtility(IPropertiesTool)
@@ -555,3 +589,30 @@ def normalize_name(request, name):
     """Use INameFromTitle normalizer on given p_name."""
     normalizer = IUserPreferredURLNormalizer(request)
     return normalizer.normalize(name)
+
+
+def get_modified_attrs(modified_event):
+    """Useful in a IObjectModifiedEvent to get what fields were actually edited."""
+    mod_attrs = [name for attr in modified_event.descriptions
+                 for name in attr.attributes]
+    return mod_attrs
+
+
+def object_values(context, class_name):
+    """Behaves like objectValues from Zope but as meta_type for
+       DX content_type is always the same, check the contained element class name."""
+    res = []
+    for contained in context.objectValues():
+        if contained.__class__.__name__ == class_name:
+            res.append(contained)
+    return res
+
+
+def object_ids(context, class_name):
+    """Behaves like objectIds from Zope but as meta_type for
+       DX content_type is always the same, check the contained element class name."""
+    res = []
+    for contained in context.objectValues():
+        if contained.__class__.__name__ == class_name:
+            res.append(contained.getId())
+    return res
